# -*- coding: UTF-8 -*-
from py.test import raises
import exceptions
from scribe import backend
from os.path import isdir, isfile
from os import system, listdir
from creole import parsedico
from time import sleep
import ftplib, imaplib

dico = parsedico.parse_dico()

def test_create_niveau():
    backend.ajout_groupe('tnivo', 'niveau', domaine='', optrw='')

def test_create_classe():
    backend.ajout_classe('tclasse', 'tnivo')
    assert isdir('/home/workgroups/tclasse/donnees')
    assert isdir('/home/workgroups/profs-tclasse')
    assert 'tnivo' == backend.get_niveau('tclasse')

def test_create_gropupe():
    backend.ajout_groupe('tgroupe', 'groupe', domaine='', optrw='dt')
    assert isdir('/home/workgroups/tgroupe/travail')

def test_create_eleve():
    backend.ajout_eleve('televe', 'tpass', 'nom', 'prenom', '01021980', 'tclasse', '666',
                  civilite='1', domaine='restreint', quota='20', profil='1', shell=False)
    assert isdir('/home/t/televe/MailDir')
    # liens classe -> eleves
    assert isdir('/home/workgroups/profs-tclasse/eleves/televe')

def test_create_prof():
    backend.ajout_prof('tprof', 'tpass', 'nom', 'prenom', '01021980', classe='tclasse', civilite='1', 
               mail='local', quota='0', profil='1', shell=False)
    assert isdir('/home/t/tprof/MailDir')

def test_inscription_prof():
    backend.inscription('tprof', 'profs-tclasse')
    assert isdir('/home/t/tprof/.ftp/profs-tclasse')

def test_inscription_eleve():
    backend.inscription('televe', 'tgroupe')
    assert isdir('/home/t/televe/.ftp/tgroupe')

def test_smb_perso_eleve():
    system('mkdir -p /tmp/home')
    system('smbmount //127.0.0.1/televe /tmp/home -o username=televe,password=tpass')
    system('touch /tmp/home/fichier.txt')
    assert isfile('/tmp/home/fichier.txt')
    system('rm -f /tmp/home/fichier.txt')
    assert not isfile('/tmp/home/fichier.txt')
    # test antivirus temps réel
    if dico['smb_vscan'] == 'oui':
        system("""echo 'X5O!P%@AP[4\PZX54(P^)7CC)7}$EICAR-STANDARD-ANTIVIRUS-TEST-FILE!$H+H*' > /tmp/home/virus.txt""")
        sleep(1)
        assert not isfile('/tmp/home/virus.txt')
        system('rm -f /tmp/home/virus.txt')
    system('umount /tmp/home/')

def test_smb_classe_eleve():
    system('mkdir -p /tmp/classe')
    system('smbmount //127.0.0.1/tclasse /tmp/classe -o username=televe,password=tpass')
    system('touch /tmp/classe/travail/fichier.txt')
    assert isfile('/tmp/classe/travail/fichier.txt')
    system('rm -f /tmp/classe/travail/fichier.txt')
    assert not isfile('/tmp/classe/travail/fichier.txt')
    system('touch /tmp/classe/donnees/fichier.txt')
    assert not isfile('/tmp/classe/donnees/fichier.txt')
    system('rm -f /tmp/classe/donnees/fichier.txt')
    system('umount /tmp/classe')

def test_smb_equipe_prof():
    system('mkdir -p /tmp/equipe')
    system('smbmount //127.0.0.1/profs-tclasse /tmp/equipe -o username=tprof,password=tpass')
    assert isdir('/tmp/equipe/eleves/televe')
    # pas le droit de scanner le privé !
    raises(exceptions.OSError, listdir, '/tmp/equipe/eleves/televe/prive')
    system('umount /tmp/equipe')

def test_ftp_eleve():
    if dico['ftp_perso'] == 'oui':
        session = ftplib.FTP('127.0.0.1', 'televe', 'tpass')
        session.quit()

def test_mail_eleve():
    mail = imaplib.IMAP4()
    mail.login('televe', 'tpass')
    mail.select('inbox')
    assert mail.fetch(1, "(body[header])")[1][0][1].startswith('Received:')
    mail.close()    
    mail.logout()

def test_mail_prof():
    mail = imaplib.IMAP4()
    mail.login('tprof', 'tpass')
    mail.select('inbox')
    assert mail.fetch(1, "(body[header])")[1][0][1].startswith('Received:')
    mail.close()    
    mail.logout()

def test_desinscription():
    backend.desinscription('televe', 'tgroupe')
    assert not isdir('/home/t/televe/.ftp/tgroupe')

def test_delete_eleve():
    backend.del_user('televe', remove_data=True)
    assert not isdir('/home/t/televe')

def test_delete_prof():
    backend.del_user('tprof', remove_data=True)
    assert not isdir('/home/t/tprof')

def test_delete_shares():
    backend.del_share('tclasse', rmdir=True, sync=False)
    assert not isdir('/home/workgroups/tclasse')
    backend.del_share('profs-tclasse', rmdir=True, sync=False)
    assert not isdir('/home/workgroups/profs-tclasse')
    backend.del_share('tgroupe', rmdir=True, sync=True)
    assert not isdir('/home/workgroups/tgroupe')

def test_delete_groups():
    system("rm -rf /var/lib/sympa/expl/i-*/tclasse/")
    backend.del_group('tclasse')
    backend.del_group('profs-tclasse')
    backend.del_group('tnivo')
    backend.del_group('tgroupe')

